Cloud Builder
=============

.. |GitHub CI Action| image:: https://github.com/OSInside/cloud-builder/workflows/CILint/badge.svg
   :target: https://github.com/OSInside/cloud-builder/actions

|GitHub CI Action|

The Cloud Builder project provides a collection of services which
allows you to stand up a package building backend to build software
packages through a messaging API. Primarily **rpm** packages but also
other package formats like **deb**, **pacman** and alike are possible.

For more information see: https://osinside.github.io/cloud-builder
